==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRewriteFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRewriteFluentImpl<A extends HTTPRewriteFluent<A>> extends BaseFluent<A> implements HTTPRewriteFluent<A>{
  public HTTPRewriteFluentImpl() {
  }
  public HTTPRewriteFluentImpl(HTTPRewrite instance) {
    this.withAuthority(instance.getAuthority()); 
    this.withUri(instance.getUri()); 
  }
  private String authority;
  private String uri;
  public String getAuthority() {
    return this.authority;
  }
  public A withAuthority(String authority) {
    this.authority=authority; return (A) this;
  }
  public Boolean hasAuthority() {
    return this.authority != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPRewriteFluentImpl that = (HTTPRewriteFluentImpl) o;
    if (authority != null ? !authority.equals(that.authority) :that.authority != null) return false;
    if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authority,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authority != null) { sb.append("authority:"); sb.append(authority + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRewriteFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRewriteFluentImpl<A extends HTTPRewriteFluent<A>> extends BaseFluent<A> implements HTTPRewriteFluent<A>{
  public HTTPRewriteFluentImpl() {
  }
  public HTTPRewriteFluentImpl(HTTPRewrite instance) {
    if (instance != null) {
      this.withAuthority(instance.getAuthority());
      this.withUri(instance.getUri());
    }
  }
  private String authority;
  private String uri;
  public String getAuthority() {
    return this.authority;
  }
  public A withAuthority(String authority) {
    this.authority=authority; return (A) this;
  }
  public Boolean hasAuthority() {
    return this.authority != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRewriteFluentImpl that = (HTTPRewriteFluentImpl) o;
    if (!java.util.Objects.equals(authority, that.authority)) return false;

    if (!java.util.Objects.equals(uri, that.uri)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authority,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authority != null) { sb.append("authority:"); sb.append(authority + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}
